@@ -1,7 +1,7 @@
 package Kafka::Librd;
 use strict;
 use warnings;
-our $VERSION = "0.04";
+our $VERSION = "0.05";
 my $XS_VERSION = $VERSION;
 $VERSION = eval $VERSION;
 
@@ -17,7 +17,7 @@ Kafka::Librd - bindings for librdkafka
 
 =head1 VERSION
 
-This document describes Kafka::Librd version 0.04
+This document describes Kafka::Librd version 0.05
 
 =head1 SYNOPSIS
 
@@ -103,7 +103,7 @@ unsubscribe from the current subsctiption set
     $msg = $kafka->consumer_poll($timeout_ms)
 
 poll for messages or events. If any message or event received, returns
-L</Kafka::Librd::Message> object. If C<$msg->err> for returned object is zero
+L</Kafka::Librd::Message> object. If C<<$msg->err>> for returned object is zero
 (RD_KAFKA_RESP_ERR_NO_ERROR), then it is a proper message, otherwise it is an
 event or an error.
 
